pub struct FixedVecFromIterBuilder<T: Storable<W>, W: Word, E: Endianness, I: IntoIterator<Item = T>> { /* private fields */ }Expand description
A builder for creating a FixedVec from an iterator.
This builder is designed for streaming data from an iterator without first
collecting it into a slice. It requires the bit_width to be specified
manually, as it cannot analyze the data in advance.
Implementations
Sourceimpl<T, W, E, I> FixedVecFromIterBuilder<T, W, E, I>where
T: Storable<W>,
W: Word,
E: Endianness,
I: IntoIterator<Item = T>,
BufBitWriter<E, MemWordWriterVec<W, Vec<W>>>: BitWrite<E, Error = Infallible>,
impl<T, W, E, I> FixedVecFromIterBuilder<T, W, E, I>where
T: Storable<W>,
W: Word,
E: Endianness,
I: IntoIterator<Item = T>,
BufBitWriter<E, MemWordWriterVec<W, Vec<W>>>: BitWrite<E, Error = Infallible>,