pub trait DefaultParams: Sized {
type W: Word;
type E: Endianness;
}Expand description
A sealed trait to associate an element type T with its default storage
word W and Endianness E.
This allows for the creation of convenient type aliases like UFixedVec<T>
that do not require specifying all generic parameters.
Required Associated Types
Sourcetype E: Endianness
type E: Endianness
The default endianness (usually LittleEndian).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".