pub trait Word:
Bounded
+ ToPrimitive
+ Word
+ NumCast
+ Copy
+ Send
+ Sync
+ Debug
+ IntoAtomic
+ 'static {
const BITS: usize = _;
}Expand description
A trait that abstracts over the primitive unsigned integer types that can
serve as the storage words in a FixedVec.
This trait establishes a contract for what constitutes a “machine word” for storage, providing access to its size in bits and requiring the necessary traits for bit-level operations.
Provided Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".