Module prelude

Module prelude 

A prelude for compressed-intvec.

This prelude is automatically imported when you use use compressed-intvec::prelude::*;. It exports all the most common types and traits.

Re-exports

pub use crate::fixed::atomic::AtomicFixedVec;
pub use crate::fixed::atomic::SAtomicFixedVec;
pub use crate::fixed::atomic::UAtomicFixedVec;
pub use crate::fixed::builder::FixedVecBuilder;
pub use crate::fixed::builder::FixedVecFromIterBuilder;
pub use crate::fixed::iter::FixedVecIntoIter;
pub use crate::fixed::iter::FixedVecIter;
pub use crate::fixed::traits::Storable as FixedStorable;
pub use crate::fixed::traits::Word;
pub use crate::fixed::BEFixedVec;
pub use crate::fixed::BESFixedVec;
pub use crate::fixed::BitWidth;
pub use crate::fixed::Error as FixedVecError;
pub use crate::fixed::FixedVec;
pub use crate::fixed::LEFixedVec;
pub use crate::fixed::LESFixedVec;
pub use crate::fixed::SFixedVec;
pub use crate::fixed::UFixedVec;
pub use crate::variable::builder::VarVecBuilder;
pub use crate::variable::builder::VarVecFromIterBuilder;
pub use crate::variable::codec::Codec;
pub use crate::variable::iter::VarVecIntoIter;
pub use crate::variable::iter::VarVecIter;
pub use crate::variable::reader::VarVecReader;
pub use crate::variable::seq_reader::VarVecSeqReader;
pub use crate::variable::slice::VarVecSlice;
pub use crate::variable::slice::VarVecSliceIter;
pub use crate::variable::traits::Storable as VariableStorable;
pub use crate::variable::BESVarVec;
pub use crate::variable::BEVarVec;
pub use crate::variable::LESVarVec;
pub use crate::variable::LEVarVec;
pub use crate::variable::SVarVec;
pub use crate::variable::UVarVec;
pub use crate::variable::VarVec;
pub use crate::variable::VarVecError;
pub use crate::variable::BEIntVec;Deprecated
pub use crate::variable::BESIntVec;Deprecated
pub use crate::variable::IntVec;Deprecated
pub use crate::variable::IntVecBuilder;Deprecated
pub use crate::variable::IntVecError;Deprecated
pub use crate::variable::IntVecFromIterBuilder;Deprecated
pub use crate::variable::IntVecIntoIter;Deprecated
pub use crate::variable::IntVecIter;Deprecated
pub use crate::variable::IntVecReader;Deprecated
pub use crate::variable::IntVecSeqReader;Deprecated
pub use crate::variable::IntVecSlice;Deprecated
pub use crate::variable::IntVecSliceIter;Deprecated
pub use crate::variable::LEIntVec;Deprecated
pub use crate::variable::LESIntVec;Deprecated
pub use crate::variable::SIntVec;Deprecated
pub use crate::variable::UIntVec;Deprecated
pub use crate::variable::VariableCodecSpec;Deprecated
pub use crate::seq::BESSeqVec;
pub use crate::seq::BESeqVec;
pub use crate::seq::LESSeqVec;
pub use crate::seq::LESeqVec;
pub use crate::seq::SSeqVec;
pub use crate::seq::SeqIter;
pub use crate::seq::SeqVec;
pub use crate::seq::SeqVecBuilder;
pub use crate::seq::SeqVecError;
pub use crate::seq::SeqVecFromIterBuilder;
pub use crate::seq::SeqVecIntoIter;
pub use crate::seq::SeqVecIter;
pub use crate::seq::SeqVecReader;
pub use crate::seq::SeqVecSlice;
pub use crate::seq::USeqVec;

Macros

fixed_vec
Creates a FixedVec with default parameters.
int_vec
Creates a LEVarVec (a VarVec of u64s) containing the given elements.
seq_vec
Creates a LESeqVec containing the given sequences.
sfixed_vec
Creates a FixedVec of signed integers (forces i64).
sint_vec
Creates a LESVarVec (a VarVec of i64s) containing the given elements.
sseq_vec
Creates a LESeqVec of signed integers (forces i64).