Module builder

Module builder 

Builders for constructing an VarVec.

This module provides the two primary builders for creating an VarVec:

  • VarVecBuilder: For building from an existing slice of data. This is the most flexible builder, as it can analyze the data to automatically select an optimal compression codec.
  • VarVecFromIterBuilder: For building from an iterator. This is suitable for large datasets that are generated on the fly, but it requires the compression codec to be specified manually.

Structs

VarVecBuilder
A builder for creating an VarVec from a slice of integers.
VarVecFromIterBuilder
A builder for creating an VarVec from an iterator.