Module iter

Module iter 

Iterators for VarVec.

This module provides the iterators for VarVec. Due to the nature of variable-length encoding, an VarVec is immutable once created, as modifying an element would require re-encoding the rest of the data stream.

Structs

VarVecIntoIter
An owning iterator over the values of an VarVec.
VarVecIter
A borrowing iterator over the values of an VarVec.