IntVec

Type Alias IntVec 

pub type IntVec<T, E, B = Vec<u64>> = VarVec<T, E, B>;
👎Deprecated since 0.6.0:

renamed to VarVec; use VarVec instead

Deprecated alias for VarVec. Use VarVec instead.

Deprecation Notice

This type has been renamed to VarVec for consistency with the module naming convention (variable → VarVec). This alias will be removed in a future major release.

Aliased Type

pub struct IntVec<T, E, B = Vec<u64>> { /* private fields */ }