MutProxy

Struct MutProxy 

pub struct MutProxy<'a, T, W, E, B>
where T: Storable<W>, W: Word, E: Endianness, B: AsRef<[W]> + AsMut<[W]>,
{ /* private fields */ }
A proxy object for mutable access to an element within a FixedVec.

This struct is returned by FixedVec::at_mut. It holds a temporary copy of an element’s value. When the proxy is dropped, its Drop implementation writes the (potentially modified) value back into the parent vector. This “copy-on-read, write-on-drop” mechanism allows for an API that feels like direct mutable access.

Implementations

Source

impl<'a, T, W, E, B> MutProxy<'a, T, W, E, B>
where T: Storable<W>, W: Word, E: Endianness, B: AsRef<[W]> + AsMut<[W]>,

pub fn into_inner(self) -> T

Consumes the proxy, returning the current value without writing it back.

This can be used to avoid the overhead of a write operation if the value was read but not modified.